# sz-sdk-json-type-definition

## HTML and JSON

| Senzing method | HTML | JSON |
| -------------- | ---- | ---- |
| SzConfigExport                            | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzConfigExportResponse.html)                            | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzConfigExportResponse.json)                            |
| SzConfigGetDataSourceRegistry             | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzConfigGetDataSourceRegistryResponse.html)             | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzConfigGetDataSourceRegistryResponse.json)             |
| SzConfigManagerGetConfigRegistry          | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzConfigManagerGetConfigRegistryResponse.html)          | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzConfigManagerGetConfigRegistryResponse.json)          |
| SzConfigRegisterDataSource                | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzConfigRegisterDataSourceResponse.html)                | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzConfigRegisterDataSourceResponse.json)                |
| SzDiagnosticCheckRepositoryPerformance    | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzDiagnosticCheckRepositoryPerformanceResponse.html)    | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzDiagnosticCheckRepositoryPerformanceResponse.json)    |
| SzDiagnosticGetFeature                    | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzDiagnosticGetFeatureResponse.html)                    | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzDiagnosticGetFeatureResponse.json)                    |
| SzDiagnosticGetRepositoryInfo             | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzDiagnosticGetRepositoryInfoResponse.html)             | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzDiagnosticGetRepositoryInfoResponse.json)             |
| SzEngineAddRecord                         | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineAddRecordResponse.html)                         | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineAddRecordResponse.json)                         |
| SzEngineDeleteRecord                      | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineDeleteRecordResponse.html)                      | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineDeleteRecordResponse.json)                      |
| SzEngineFetchNext                         | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineFetchNextResponse.html)                         | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineFetchNextResponse.json)                         |
| SzEngineFindInterestingEntitiesByEntityId | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineFindInterestingEntitiesByEntityIdResponse.html) | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineFindInterestingEntitiesByEntityIdResponse.json) |
| SzEngineFindInterestingEntitiesByRecordId | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineFindInterestingEntitiesByRecordIdResponse.html) | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineFindInterestingEntitiesByRecordIdResponse.json) |
| SzEngineFindNetworkByEntityId             | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineFindNetworkByEntityIdResponse.html)             | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineFindNetworkByEntityIdResponse.json)             |
| SzEngineFindNetworkByRecordId             | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineFindNetworkByRecordIdResponse.html)             | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineFindNetworkByRecordIdResponse.json)             |
| SzEngineFindPathByEntityId                | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineFindPathByEntityIdResponse.html)                | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineFindPathByEntityIdResponse.json)                |
| SzEngineFindPathByRecordId                | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineFindPathByRecordIdResponse.html)                | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineFindPathByRecordIdResponse.json)                |
| SzEngineGetEntityByEntityId               | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineGetEntityByEntityIdResponse.html)               | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineGetEntityByEntityIdResponse.json)               |
| SzEngineGetEntityByRecordId               | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineGetEntityByRecordIdResponse.html)               | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineGetEntityByRecordIdResponse.json)               |
| SzEngineGetRecordPreview                  | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineGetRecordPreviewResponse.html)                  | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineGetRecordPreviewResponse.json)                  |
| SzEngineGetRecord                         | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineGetRecordResponse.html)                         | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineGetRecordResponse.json)                         |
| SzEngineGetRedoRecord                     | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineGetRedoRecordResponse.html)                     | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineGetRedoRecordResponse.json)                     |
| SzEngineGetStats                          | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineGetStatsResponse.html)                          | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineGetStatsResponse.json)                          |
| SzEngineGetVirtualEntityByRecordId        | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineGetVirtualEntityByRecordIdResponse.html)        | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineGetVirtualEntityByRecordIdResponse.json)        |
| SzEngineHowEntityByEntityId               | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineHowEntityByEntityIdResponse.html)               | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineHowEntityByEntityIdResponse.json)               |
| SzEngineProcessRedoRecord                 | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineProcessRedoRecordResponse.html)                 | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineProcessRedoRecordResponse.json)                 |
| SzEngineReevaluateEntity                  | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineReevaluateEntityResponse.html)                  | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineReevaluateEntityResponse.json)                  |
| SzEngineReevaluateRecord                  | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineReevaluateRecordResponse.html)                  | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineReevaluateRecordResponse.json)                  |
| SzEngineSearchByAttributes                | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineSearchByAttributesResponse.html)                | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineSearchByAttributesResponse.json)                |
| SzEngineStreamExportJsonEntityReport      | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineStreamExportJsonEntityReportResponse.html)      | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineStreamExportJsonEntityReportResponse.json)      |
| SzEngineWhyEntities                       | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineWhyEntitiesResponse.html)                       | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineWhyEntitiesResponse.json)                       |
| SzEngineWhyRecordInEntity                 | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineWhyRecordInEntityResponse.html)                 | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineWhyRecordInEntityResponse.json)                 |
| SzEngineWhyRecords                        | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineWhyRecordsResponse.html)                        | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineWhyRecordsResponse.json)                        |
| SzEngineWhySearch                         | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzEngineWhySearchResponse.html)                         | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzEngineWhySearchResponse.json)                         |
| SzProductGetLicense                       | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzProductGetLicenseResponse.html)                       | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzProductGetLicenseResponse.json)                       |
| SzProductGetVersion                       | [HTML](https://garage.senzing.com/sz-sdk-json-type-definition/responses-html/SzProductGetVersionResponse.html)                       | [JSON](https://garage.senzing.com/sz-sdk-json-type-definition/responses-json/SzProductGetVersionResponse.json)                       |
